/************************************************************************************************
** File:        timer.c
** Description: Implementation of timer for sample project to blink LEDs
** Version:		1.0
**
*
** Copyright 2015 Zilog Inc. ALL RIGHTS RESERVED.
*
*************************************************************************************************
* The source code in this file was written by an authorized Zilog employee or a licensed 
* consultant. The source code has been verified to the fullest extent possible. 
*
* Permission to use this code is granted on a royalty-free basis. However, users are cautioned to
* authenticate the code contained herein. 
* 
* ZILOG DOES NOT GUARANTEE THE VERACITY OF THIS SOFTWARE; ANY SOFTWARE CONTAINED HEREIN IS
* PROVIDED "AS IS." NO WARRANTIES ARE GIVEN, WHETHER EXPRESS, IMPLIED, OR STATUTORY, INCLUDING
* IMPLIED WARRANTIES OF FITNESS FOR PARTICULAR PURPOSE OR MERCHANTABILITY. IN NO EVENT WILL ZILOG
* BE LIABLE FOR ANY SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES OR ANY LIABILITY IN TORT,
* NEGLIGENCE, OR OTHER LIABILITY INCURRED AS A RESULT OF THE USE OF THE SOFTWARE, EVEN IF ZILOG 
* HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. ZILOG ALSO DOES NOT WARRANT THAT THE USE 
* OF THE SOFTWARE, OR OF ANY INFORMATION CONTAINED THEREIN WILL NOT INFRINGE ANY PATENT, 
* COPYRIGHT, OR TRADEMARK OF ANY THIRD PERSON OR ENTITY.

* THE SOFTWARE IS NOT FAULT-TOLERANT AND IS NOT DESIGNED, MANUFACTURED OR INTENDED FOR USE IN 
* CONJUNCTION WITH ON-LINE CONTROL EQUIPMENT, IN HAZARDOUS ENVIRONMENTS, IN APPLICATIONS 
* REQUIRING FAIL-SAFE PERFORMANCE, OR WHERE THE FAILURE OF THE SOFTWARE COULD LEAD DIRECTLY TO 
* DEATH, PERSONAL INJURY OR SEVERE PHYSICAL OR ENVIRONMENTAL DAMAGE (ALL OF THE FOREGOING, 
* "HIGH RISK ACTIVITIES"). ZILOG SPECIFICALLY DISCLAIMS ANY EXPRESS OR IMPLIED WARRANTY TO HIGH 
* RISK ACTIVITIES.
*
************************************************************************************************/

#include "z32F1281.h"
#include "timer.h"

/*********************************************************************
 *	Init_Timer
 *	
 *	Initializes Timer 0 to turn on and off the LEDs in series
 *	
 *	Requires:
 *		Nothing
 *	Returns: 
 *		Nothing
 **********************************************************************/

void Init_Timer(void)
{	
	
	SCU->MCCR3 &= 0x0000FFFF;
	SCU->MCCR3 |= 0x06800000;			//Set for External Clock (8 Mhz) with a 128 divisor
	
	SCU->PER1 |= (1 << SCU_PER1_TIMER0_Pos);			//Enable Timer0 Peripheral
	SCU->PCER1 |= (1 << SCU_PCER1_TIMER0_Pos);			//Enable Timer0 Peripheral clock
	
	T0->CR2 = 0x00;								//Make sure it is disabled
	T0->CR1 = 0x0040;							//Select clock configured in MCCR3
	T0->PRS = 124;								//Prescaler = 125, giving 500 ticks per second
	T0->GRA = 250;								//Set to interrupt every 500mS
	T0->IER = 0x04;								//Interrupt on Match on period

	NVIC_EnableIRQ(TIMER0_IRQn);	//Enable Interrupt in NVIC

	T0->CR2 = 0x03;								//Clear and Start
		
}

/*********************************************************************
 *	TIMER0_IRQHandler
 *	
 *	Interrupt handler override for Timer0 Interrupt.
 *	
 *	Requires:
 *		Nothing
 *	Returns: 
 *		Nothing
 **********************************************************************/

void TIMER0_IRQHandler(void)
{
		static uint16_t count=0;

			T0->SR = T0->SR;			//Clear interrupt
	
			++count;
			if (count > 1)
				count = 0;
		
			PD->BCR = 0x0300;			//Turn all off
			PD->BSR = (1 << (count+8));		//Turn on the led
}

